sizeVerticalBias property
ScreenSize
get
sizeVerticalBias
The size of the screen with the longest side as the width.
Implementation
ScreenSize get sizeVerticalBias => this._sizeVerticalBias;
The size of the screen with the longest side as the width.
ScreenSize get sizeVerticalBias => this._sizeVerticalBias;